RestClient class abstract

Annotations
  • @RestApi.new()

Constructors

RestClient(Dio dio, {String? baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptParticipantInLobby(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<RtcData>>
addParticipantToLobby(Map<String, dynamic> body) Future<BaseResponse<RtcData>>
dispatchAgent(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<AgentDispatchData>>
endMeeting(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
getAttendanceListForParticipant(String selfIdentity, String meetingId) Future<BaseListResponse<ParticipantAttendanceData>>
getAudioPermission(String selfIdentity, String meetingId) Future<BaseResponse<WebinarPermissionModel>>
getChatAttachmentConsent(String selfIdentity, String meetingId) Future<BaseResponse<ChatAttachmentConsentModel>>
getFeatures(String meetingUid) Future<BaseResponse<FeatureData>>
getHostToken(String meetingUid) Future<BaseResponse<HostTokenModel>>
getMeetingDetails(String meetingUid, String secret) Future<BaseResponse<MeetingDetailsModel>>
getMeetingJoinDetail(String token, Map<String, dynamic> body) Future<BaseResponse<RtcData>>
getParticipantConsentList(String selfIdentity, String meetingId, String sessionId) Future<BaseListResponse<RemoteParticipantConsent>>
getRecordingDispatchedId(String token, String selfIdentity, String meetingUid) Future<BaseResponse<RecordingDispatchData>>
getScreenShareConsent(String selfIdentity, String meetingId) Future<BaseResponse<ScreenShareConsentModel>>
getSessionDetails(String selfIdentity, String meetingId) Future<BaseResponse<SessionDetailsData>>
getVideoPermission(String selfIdentity, String meetingId) Future<BaseResponse<WebinarPermissionModel>>
getWhiteBoardData(String selfIdentity, String meetingId) Future<BaseListResponse<WhiteboardData>>
licenceVerify(Map<String, dynamic> body) Future<BaseResponse<LicenceVerifyModel>>
makeCoHost(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
meetingTimeExtend(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParticipant(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
setTranscriptionLanguage(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
startRecording(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<EgressData>>
startRecordingConsent(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
startTranscription(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
stopRecording(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
stopTranscription(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
toString() String
A string representation of this object.
inherited
translateText(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<TranslationData>>
updateAudioPermission(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<WebinarPermissionModel>>
updateChatAttachmentConsent(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<ChatAttachmentConsentModel>>
updateParticipantName(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
updateRecordingConsent(String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<ConsentStatusData>>
updateScreenShareConsent(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<ScreenShareConsentModel>>
updateTranscriptionLanguage(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse>
updateVideoPermission(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<WebinarPermissionModel>>
updateWorkshopMicPermission(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<WorkshopPermissionModel>>
updateWorkshopVideoPermission(String token, String selfIdentity, Map<String, dynamic> body) Future<BaseResponse<WorkshopPermissionModel>>
uploadFile(File file, {ProgressCallback? onSendProgress}) Future<BaseResponse<UploadData>>
verifyCommonMeetingPassword(Map<String, dynamic> body) Future<BaseResponse<EventPasswordProtectedData>>
verifyHostToken(Map<String, dynamic> body) Future<BaseResponse<HostTokenModel>>
verifyMeetingPassword(Map<String, dynamic> body) Future<BaseResponse<EventPasswordProtectedData>>

Operators

operator ==(Object other) bool
The equality operator.
inherited