DatadogObsConfig class

Constructors

DatadogObsConfig({required String clientToken, required String applicationId, required String env, DatadogSite site = DatadogSite.us3, String? serviceName, String? version})
DatadogObsConfig.fromJson(Map<String, dynamic> json)
factory

Properties

applicationId String
final
clientToken String
final
env String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
final
site → DatadogSite
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited