ObservabilityConfigModel class
Constructors
- ObservabilityConfigModel({DatadogObsConfig? datadog, SentryObsConfig? sentry})
-
const
-
ObservabilityConfigModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- datadog → DatadogObsConfig?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentry → SentryObsConfig?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited