Utils class
Constructors
-
Utils()
-
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
calculateMinutesSince(DateTime? joinedAt)
→ int
-
-
decodeUnicode(String? input)
→ String
-
-
-
-
-
-
-
-
-
formatTimestampToTime(int? timestamp)
→ String
-
-
generateUniqueColorFromInitials(String initials)
→ Color
-
-
generateWhiteboardUrl({required String meetingId, required String livekitToken})
→ String
-
-
getAndroidVersion()
→ Future<int>
-
-
getAppName()
→ Future<String>
-
-
getFormattedTranscriptToSave(List<TranscriptionModel> transcriptions)
→ String
-
-
getInitials(String? fullName)
→ String
-
-
getMetadataAttendanceId(String? metadata)
→ String
-
-
getMetadataRole(String? metadata)
→ String
-
-
getMetadataSessionUid(String? metadata)
→ String?
-
-
getParticipantType(String? metadata)
→ String
-
-
getReplyDraft(RemoteActivityData chat, {String? name})
→ ReplyMessage?
-
-
getTimeZoneId()
→ String
-
-
getTranscriptFormattedToSave(List<TranscriptionModel> transcriptions)
→ String
-
-
getTranslatedTranscriptFormattedToSave(List<TranscriptionModel> transcriptions)
→ String
-
-
hideKeyboard(BuildContext context)
→ void
-
-
isCoHost(String? metadata)
→ bool
-
-
isFileLink(String url)
→ bool
-
-
isHost(String? metadata)
→ bool
-
-
isIosSimulator()
→ Future<bool>
-
-
isLink(String message)
→ bool
-
-
isMessageSizeValid(String message)
→ bool
-
-
isMicEnabled(Map<String, dynamic>? attributes)
→ bool
-
-
isMobileDevice()
→ bool
-
-
isOnlyLink(String message)
→ bool
-
-
isPinned(RemoteActivityData? chat, RemoteActivityData? pinnedPublicChat)
→ bool
-
-
isUrl(String text)
→ bool
-
-
isValidEmail(String email)
→ bool
-
-
isVideoEnabled(Map<String, dynamic>? attributes)
→ bool
-
-
openMediaFile(String filePath, BuildContext context)
→ Future<void>
-
-
saveDataToFile(String data, String fileName)
→ Future<SavedData>
-
-
showSnackBar(BuildContext context, {required String message, String? actionText, Function? actionCallBack})
→ void
-
-
validateFile(File? file, dynamic onError(String error))
→ Future<bool>
-