RtcViewmodel class
Methods
-
acceptParticipant({required RemoteActivityData? request, required bool accept, bool acceptAll = false})
→ void
-
-
addAllMessage(List<RemoteActivityData> message)
→ void
-
-
addAnnotationStroke(String sharerIdentity, AnnotationStroke stroke)
→ void
-
-
addEmoji(EmojiMessage emoji)
→ void
-
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addMessage(RemoteActivityData message)
→ void
-
-
addParticipant(List<ParticipantTrack> participants)
→ void
-
-
addParticipantInLobby(RemoteActivityData participant)
→ void
-
-
addParticipantToConsentList(RemoteParticipant participant)
→ void
-
-
addPrivateMessage(RemoteActivityData message)
→ void
-
-
addReaction(String chatType, String emoji, RemoteActivityData chat)
→ void
-
-
addScreenShareRequest(RemoteActivityData data)
→ void
-
-
addTranscription(TranscriptionModel value)
→ void
-
-
cancelMainChatControllerEvent()
→ void
-
-
cancelPrivateChatEvents()
→ void
-
-
cancelPublicChatEvents()
→ void
-
-
cancelResetRecordingAction()
→ void
-
-
cancelRoomEvents()
→ void
-
-
cancelUploadAttachmentEvent()
→ void
-
-
checkAndAddUserToLobbyList(RemoteActivityData remoteData)
→ void
-
-
checkAndCreatePrivateChat(String? identity, String? name)
→ void
-
-
checkSessionStatus({bool asUser = false, Function? callBack})
→ void
-
-
checkTranscriptionStateAndReturn(RemoteActivityData remoteData)
→ void
-
-
clearAnnotationStrokes(String sharerIdentity)
→ void
-
-
clearRaiseHandMemory(String? identity)
→ void
-
-
clearScreenShareRequest(String identity)
→ void
-
-
collectInactiveParticipant(List<ParticipantAttendanceData>? data)
→ void
-
-
collectTranscriptionData(RemoteActivityData remoteData)
→ void
-
-
configAutoRecording()
→ void
-
-
deleteMessage(String mode, String? id, String? identity)
→ void
-
-
disableAudio()
→ void
-
-
disableVideo()
→ void
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
disposeScreenShare()
→ Future<void>
-
-
editMessage(String mode, String? id, String? identity, String? message)
→ void
-
-
editPrivateMessage(String updatedMessage, String identity)
→ void
-
-
editPublicMessage(String updatedMessage)
→ void
-
-
enableAudio()
→ Future<void>
-
-
enableVideo()
→ void
-
-
endMeetingForAll()
→ void
-
-
fetchAndStoreSessionUid()
→ Future<void>
-
-
fetchLanguages()
→ Future<List<LanguageModel>>
-
-
getAdminType()
→ String?
-
-
getAnnotationStrokes(String sharerIdentity)
→ List<AnnotationStroke>
-
-
getAttendanceListForParticipant()
→ void
-
-
getAudioPermission()
→ void
-
-
getCameraAlpha()
→ double
-
-
getChatAttachmentConsent()
→ void
-
-
getCoHost()
→ bool
-
-
getHostControls()
→ void
-
-
getLobbyRequestList()
→ List<RemoteActivityData>
-
-
getMeetingEndDate()
→ String?
-
-
getMessageList()
→ List<RemoteActivityData>
-
-
getMicAlpha()
→ double
-
-
getParticipantConsentList({VoidCallback? onLoaded})
→ void
-
-
getParticipantDrawerConsent()
→ void
-
-
getParticipantList()
→ List<ParticipantTrack>
-
-
getParticipantNameByIdentity(String? identity)
→ String
-
-
getParticipantNameOrNull(String? identity)
→ String?
-
-
getPrivateChatForParticipant(String identity)
→ List<RemoteActivityData>
-
-
getPrivateChatIdentity()
→ String
-
-
getPrivateChatUserName()
→ String
-
-
getPrivateMessage()
→ Map<String, PrivateChatModel>
-
-
getRaisePosition(String identity)
→ int?
-
-
getRecordingDispatchedId({bool isNeedToShowError = true, VoidCallback? onComplete})
→ void
-
-
getScreenShareConsent()
→ void
-
-
getSessionId()
→ String?
-
-
getUnReadCount()
→ int
-
-
getUnreadCountPrivateChat()
→ int
-
-
getVideoPermission()
→ void
-
-
getWhiteboardData()
→ void
-
-
handleCaptionFromRaw(String text, bool isFinal, String participantIdentity)
→ void
-
-
handleCaptionTranscriptionOld(CaptionData data)
→ void
-
-
handleReaction(RemoteActivityData remoteData)
→ void
-
-
handleScreenShareRequest(bool allow, RemoteActivityData request)
→ void
-
-
hasAlreadyAcceptedConsent()
→ bool
-
-
hasPrivateChat(String identity)
→ bool
-
-
hasRequestedAnnotationSnapshot(String key)
→ bool
-
-
increaseUnreadCount()
→ void
-
-
increaseUnreadPrivateChatCount()
→ void
-
-
isAutoMeetingEndEnable()
→ bool
-
-
isCoHost()
→ bool
-
-
isHandRaised(String identity)
→ bool
-
-
isHost()
→ bool
-
-
isScreenSharePermissionNeeded()
→ bool
-
-
isVisibleForCoHost(String role, String targetRole)
→ bool
-
-
isVisibleForHost(String role, String targetRole)
→ bool
-
-
locallyUpdateRecordingConsentStatus(bool status)
→ void
-
-
lowerHand(String? identity)
→ void
-
-
makeCoHost(String identity, bool isCoHost)
→ void
-
-
markAnnotationSnapshotRequested(String key)
→ void
-
-
meetingTimeExtend()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pauseCameraForHandoff()
→ Future<bool>
-
Releases the LiveKit camera so the native camera UI can use it.
Returns whether the camera was active, so the caller can restore it.
-
publishAnnotationData(Room room, Map<String, dynamic> payload, {List<String>? destinationIdentities})
→ Future<void>
-
-
publishAnnotationSnapshot(Room room, String sharerIdentity, List<String> destinationIdentities)
→ Future<void>
-
-
registerCaption()
→ void
-
-
registerCaptionOld()
→ void
-
-
removeAnnotationStrokes(String sharerIdentity, List<String> ids)
→ void
-
-
removeEmojiAt(int position)
→ void
-
-
removeFromCall(String identity)
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
removeParticipantFromConsentList(String participantId)
→ void
-
-
removeScreenShareRequest(RemoteActivityData data)
→ void
-
-
replaceAnnotationStrokes(String sharerIdentity, List<AnnotationStroke> strokes)
→ void
-
-
requestChatHistory()
→ void
-
-
requestForTranscriptionState()
→ void
-
-
requestRaiseHand()
→ void
-
-
resendRecordingConsent(String? identity)
→ void
-
-
resetAnnotationSharer(String sharerIdentity)
→ void
-
-
resetProgress()
→ void
-
-
resetRecordingActionInProgressAfterDelay([int seconds = 30])
→ void
-
-
resetTranscriptionLanguage()
→ void
-
-
resetUnreadCount()
→ void
-
-
resetUnreadPrivateChatCount(PrivateChatModel person)
→ void
-
-
responseRaiseHand(RemoteActivityData action)
→ void
-
-
restorePrivateChat(RemoteActivityData remoteData)
→ void
-
-
restorePublicChat(RemoteActivityData remoteData)
→ void
-
-
resumeCameraAfterHandoff(bool wasEnabled)
→ Future<void>
-
-
saveTranscriptionLanguage(TranscriptionActionModel? liveCaptionsData)
→ void
-
-
sendAction(ActionModel action)
→ Future<void>
-
-
sendDeleteMessageAction(String mode, RemoteActivityData chat)
→ void
-
-
sendEvent(RTCEvents event)
→ void
-
-
sendMainChatControllerEvent(RTCEvents event)
→ void
-
-
sendMessageToUI(String? message)
→ void
-
-
sendPrivateAction(ActionModel action, String? identity)
→ Future<void>
-
-
sendPrivateChatEvent(RTCEvents event)
→ void
-
-
sendPrivateChatHistory(String? identity)
→ void
-
-
sendPrivateMessage(String? identity, String? name, String userMessage)
→ Future<void>
-
-
sendPublicChatEvent(RTCEvents event)
→ void
-
-
sendPublicChatHistory(String? identity)
→ void
-
-
sendPublicMessage(String userMessage)
→ Future<void>
-
-
sendUploadAttachmentEvent(RTCEvents event)
→ void
-
-
setAnnotationActive(bool active, {String? sharerIdentity})
→ void
-
-
setAnnotationColor(String color)
→ void
-
-
setAnnotationTool(String tool)
→ void
-
-
setAnnotationWidth(double width)
→ void
-
-
setAudioInterrupted(bool value)
→ void
-
-
setCoHost(bool isCoHost)
→ void
-
-
setHandRaised(RemoteActivityData remoteData)
→ void
-
-
setHandRaisedForLocal(ActionModel action)
→ void
-
-
setMyHandRaised(bool isHandRaised)
→ void
-
-
setPrivateChatIdentity(String identity)
→ void
-
-
setPrivateChatUserName(String name)
→ void
-
-
setRecording(bool isRecording)
→ void
-
-
setTranscriptionLanguage(LanguageModel selectedLanguage, Function transcriptionEnabled)
→ void
-
-
shouldUpdateReaction(List<Reaction> reactions, String identity, String newEmoji)
→ bool
-
-
startLobbyCheck()
→ void
-
-
startReactionCheck()
→ void
-
-
startRecording({bool isNeedToShowError = true})
→ void
-
-
startRecordingConsent()
→ void
-
-
startRecordingConsentFlow()
→ void
-
-
startTranscription()
→ void
-
-
startTranscriptionAgent(LanguageModel selectedLanguage)
→ void
-
-
stopHandRaisedForAll()
→ void
-
-
stopLobbyCheck()
→ void
-
-
stopRecording({bool isNeedToShowError = true})
→ void
-
-
stopTranscription()
→ void
-
-
storeMeetingDetails()
→ void
-
-
syncRaiseHand(List<RaisedHand>? serverList)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
translateText(TranscriptionModel transcriptionData, {Function? callBack})
→ void
-
-
undoLastAnnotationStroke(String sharerIdentity, String localIdentity)
→ AnnotationStroke?
-
Removes and returns the last stroke drawn by
localIdentity for undo.
-
unregisterCaption()
→ void
-
-
updateAdminList(RemoteParticipant participant)
→ void
-
-
updateAnnotationConsent(bool value)
→ void
-
-
updateAnnotationPermissionForParticipant(String participantIdentity, bool value)
→ void
-
-
updateAudioPermission(bool value)
→ void
-
-
updateAudioPermissionForParticipant(String participantIdentity, bool value)
→ void
-
-
updateChatAttachmentConsent(bool value)
→ void
-
-
updateIdentityToNameMap()
→ void
-
-
updateParticipantDrawerConsent(bool isHidden)
→ void
-
-
updateParticipantLanguage(LanguageModel transcriptionLanguage)
→ void
-
-
updateParticipantName({String? participant, required String newName})
→ void
-
-
updateRecordingConsentStatus(bool status, {bool needToUpdateLocally = false})
→ void
-
-
updateScreenShareConsent(bool value)
→ void
-
-
updateVideoPermission(bool value)
→ void
-
-
updateVideoPermissionForParticipant(String participantIdentity, bool value)
→ void
-
-
uploadAttachment(File file, Function? onUploadSuccess)
→ void
-
-
uploadPrivateAttachment(String identity, String name, File file, Function? onUploadSuccess)
→ void
-
-
verifyRecordingConsent(RemoteActivityData remoteData)
→ void
-