HostControlsData class
Constructors
- HostControlsData({required bool annotationAllowed, required bool audioPermission, required bool autoMeetingEnd, required bool chatAttachmentDownloadEnabled, required bool participantDrawer, required bool videoPermission, required bool whiteboardCollaborationEnabled, required bool isRecordingActive})
-
const
-
HostControlsData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- annotationAllowed → bool
-
final
- audioPermission → bool
-
final
- autoMeetingEnd → bool
-
final
- chatAttachmentDownloadEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecordingActive → bool
-
final
- participantDrawer → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- videoPermission → bool
-
final
- whiteboardCollaborationEnabled → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited