getTranscriptFormattedToSave static method
- @Deprecated('No longer in use. Replaced by getFormattedTranscriptToSave which handles both ' 'caption and translated caption in a unified format. Kept for reference in case ' 'separate original transcript formatting is needed again in the future.')
String
getTranscriptFormattedToSave(
- List<TranscriptionModel> transcriptions
)
Implementation
@Deprecated(
'No longer in use. Replaced by getFormattedTranscriptToSave which handles both '
'caption and translated caption in a unified format. Kept for reference in case '
'separate original transcript formatting is needed again in the future.'
)
static String getTranscriptFormattedToSave(
List<TranscriptionModel> transcriptions) {
StringBuffer contentBuffer = StringBuffer();
for (var entry in transcriptions) {
if (entry.isFinal) {
contentBuffer.writeln('${entry.name} ${entry.timestamp}');
contentBuffer.writeln(entry.transcription);
contentBuffer.writeln();
contentBuffer.writeln();
}
}
return contentBuffer.toString();
}