RtcViewmodel class

Inheritance

Constructors

RtcViewmodel(Room room, MeetingDetails meetingDetails, {bool saveAttachmentToDownloads = false})

Properties

activeAnnotationSharerIdentity String?
no setter
adminList List<RemoteParticipant?>
getter/setter pair
annotationColor String
no setter
annotationTool String
no setter
annotationWidth double
no setter
coHostCount int
getter/setter pair
context BuildContext?
getter/setter pair
dispatchId String?
getter/setter pair
emojiQueue List<EmojiMessage>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasUsedParticipantLanguage bool
no setter
isAnnotationActive bool
no setter
isAnnotationEnabled bool
getter/setter pair
isAnnotationPermissionGranted bool
getter/setter pair
isAudioInterrupted bool
getter/setter pair
isAudioModeEnable bool
getter/setter pair
isAudioPermissionEnable bool
getter/setter pair
isChatAttachmentDownloadEnable bool
getter/setter pair
isChatOpen bool
getter/setter pair
isMeetingEnded bool
getter/setter pair
isMicPermissionGranted bool
Returns whether the microphone is allowed for the local participant in Workshop Mode.
getter/setter pair
isMyHandRaised bool
no setter
isParticipantDrawerHidden bool
getter/setter pair
isParticipantPageOpen bool
getter/setter pair
isPrivateChatOpen bool
getter/setter pair
isRecording bool
no setter
isRecordingActionInProgress bool
getter/setter pair
isRecordingStartByMe bool
getter/setter pair
isScreenShareDialogOpen bool
getter/setter pair
isScreenShareEnable bool
getter/setter pair
isScreenShareRequestAccepted bool
getter/setter pair
isTranscriptionLanguageSelected bool
getter/setter pair
isTranscriptionStarter bool
no setter
isTranslationActive bool
getter/setter pair
isVideoModeEnable bool
getter/setter pair
isVideoPermissionEnable bool
getter/setter pair
isVideoPermissionGranted bool
Returns whether the camera is allowed for the local participant in Workshop Mode.
getter/setter pair
isWebinarModeEnable bool
getter/setter pair
languages List<LanguageModel>
getter/setter pair
lobbyRequestList List<RemoteActivityData>
no setter
mainChatController Stream<RTCEvents>
no setter
meetingDetails MeetingDetails
getter/setter pair
particalTranscription TranscriptionModel?
getter/setter pair
participant → LocalParticipant
no setter
participantListForConsent List<ConsentParticipant>
getter/setter pair
pendingParticipantList List<ParticipantAttendanceData>
getter/setter pair
pinnedParticipantId String?
getter/setter pair
pinnedPrivateChat RemoteActivityData?
getter/setter pair
pinnedPublicChat RemoteActivityData?
getter/setter pair
privateChatEvents Stream<RTCEvents>
no setter
privateEditDraft EditMessage?
getter/setter pair
privateMessageProgress double
getter/setter pair
privateReplyDraft ReplyMessage?
getter/setter pair
publicChatEvents Stream<RTCEvents>
no setter
publicEditDraft EditMessage?
getter/setter pair
publicMessageProgress double
getter/setter pair
publicReplyDraft ReplyMessage?
getter/setter pair
raisedHandQueue List<RaisedHand>
no setter
requestTimestamps Map<String, int>
final
room ↔ Room
getter/setter pair
roomEvents Stream<RTCEvents>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveAttachmentToDownloads bool
final
screenShareRequestCount int
no setter
screenShareRequestList List<RemoteActivityData>
getter/setter pair
selfIdentity String
no setter
sessionId String
getter/setter pair
transcriptionLanguageData TranscriptionActionModel?
getter/setter pair
transcriptionList List<TranscriptionModel>
getter/setter pair
translationLanguage LanguageModel?
getter/setter pair
uploadAttachmentController Stream<RTCEvents>
no setter

Methods

acceptParticipant({required RemoteActivityData? request, required bool accept, bool acceptAll = false}) → void
addAllMessage(List<RemoteActivityData> message) → void
addAnnotationStroke(String sharerIdentity, AnnotationStroke stroke) → void
addEmoji(EmojiMessage emoji) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addMessage(RemoteActivityData message) → void
addParticipant(List<ParticipantTrack> participants) → void
addParticipantInLobby(RemoteActivityData participant) → void
addParticipantToConsentList(RemoteParticipant participant) → void
addPrivateMessage(RemoteActivityData message) → void
addReaction(String chatType, String emoji, RemoteActivityData chat) → void
addScreenShareRequest(RemoteActivityData data) → void
addTranscription(TranscriptionModel value) → void
cancelMainChatControllerEvent() → void
cancelPrivateChatEvents() → void
cancelPublicChatEvents() → void
cancelResetRecordingAction() → void
cancelRoomEvents() → void
cancelUploadAttachmentEvent() → void
checkAndAddUserToLobbyList(RemoteActivityData remoteData) → void
checkAndCreatePrivateChat(String? identity, String? name) → void
checkSessionStatus({bool asUser = false, Function? callBack}) → void
checkTranscriptionStateAndReturn(RemoteActivityData remoteData) → void
clearAnnotationStrokes(String sharerIdentity) → void
clearRaiseHandMemory(String? identity) → void
clearScreenShareRequest(String identity) → void
collectInactiveParticipant(List<ParticipantAttendanceData>? data) → void
collectTranscriptionData(RemoteActivityData remoteData) → void
configAutoRecording() → void
deleteMessage(String mode, String? id, String? identity) → void
disableAudio() → void
disableVideo() → void
dispose() → void
Discards any resources used by the object.
inherited
disposeScreenShare() Future<void>
editMessage(String mode, String? id, String? identity, String? message) → void
editPrivateMessage(String updatedMessage, String identity) → void
editPublicMessage(String updatedMessage) → void
enableAudio() Future<void>
enableVideo() → void
endMeetingForAll() → void
fetchAndStoreSessionUid() Future<void>
fetchLanguages() Future<List<LanguageModel>>
getAdminType() String?
getAnnotationStrokes(String sharerIdentity) List<AnnotationStroke>
getAttendanceListForParticipant() → void
getAudioPermission() → void
getCameraAlpha() double
getChatAttachmentConsent() → void
getCoHost() bool
getHostControls() → void
getLobbyRequestList() List<RemoteActivityData>
getMeetingEndDate() String?
getMessageList() List<RemoteActivityData>
getMicAlpha() double
getParticipantConsentList({VoidCallback? onLoaded}) → void
getParticipantDrawerConsent() → void
getParticipantList() List<ParticipantTrack>
getParticipantNameByIdentity(String? identity) String
getParticipantNameOrNull(String? identity) String?
getPrivateChatForParticipant(String identity) List<RemoteActivityData>
getPrivateChatIdentity() String
getPrivateChatUserName() String
getPrivateMessage() Map<String, PrivateChatModel>
getRaisePosition(String identity) int?
getRecordingDispatchedId({bool isNeedToShowError = true, VoidCallback? onComplete}) → void
getScreenShareConsent() → void
getSessionId() String?
getUnReadCount() int
getUnreadCountPrivateChat() int
getVideoPermission() → void
getWhiteboardData() → void
handleCaptionFromRaw(String text, bool isFinal, String participantIdentity) → void
handleCaptionTranscriptionOld(CaptionData data) → void
handleReaction(RemoteActivityData remoteData) → void
handleScreenShareRequest(bool allow, RemoteActivityData request) → void
hasAlreadyAcceptedConsent() bool
hasPrivateChat(String identity) bool
hasRequestedAnnotationSnapshot(String key) bool
increaseUnreadCount() → void
increaseUnreadPrivateChatCount() → void
isAutoMeetingEndEnable() bool
isCoHost() bool
isHandRaised(String identity) bool
isHost() bool
isScreenSharePermissionNeeded() bool
isVisibleForCoHost(String role, String targetRole) bool
isVisibleForHost(String role, String targetRole) bool
locallyUpdateRecordingConsentStatus(bool status) → void
lowerHand(String? identity) → void
makeCoHost(String identity, bool isCoHost) → void
markAnnotationSnapshotRequested(String key) → void
meetingTimeExtend() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pauseCameraForHandoff() Future<bool>
Releases the LiveKit camera so the native camera UI can use it. Returns whether the camera was active, so the caller can restore it.
publishAnnotationData(Room room, Map<String, dynamic> payload, {List<String>? destinationIdentities}) Future<void>
publishAnnotationSnapshot(Room room, String sharerIdentity, List<String> destinationIdentities) Future<void>
registerCaption() → void
registerCaptionOld() → void
removeAnnotationStrokes(String sharerIdentity, List<String> ids) → void
removeEmojiAt(int position) → void
removeFromCall(String identity) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeParticipantFromConsentList(String participantId) → void
removeScreenShareRequest(RemoteActivityData data) → void
replaceAnnotationStrokes(String sharerIdentity, List<AnnotationStroke> strokes) → void
requestChatHistory() → void
requestForTranscriptionState() → void
requestRaiseHand() → void
resendRecordingConsent(String? identity) → void
resetAnnotationSharer(String sharerIdentity) → void
resetProgress() → void
resetRecordingActionInProgressAfterDelay([int seconds = 30]) → void
resetTranscriptionLanguage() → void
resetUnreadCount() → void
resetUnreadPrivateChatCount(PrivateChatModel person) → void
responseRaiseHand(RemoteActivityData action) → void
restorePrivateChat(RemoteActivityData remoteData) → void
restorePublicChat(RemoteActivityData remoteData) → void
resumeCameraAfterHandoff(bool wasEnabled) Future<void>
saveTranscriptionLanguage(TranscriptionActionModel? liveCaptionsData) → void
sendAction(ActionModel action) Future<void>
sendDeleteMessageAction(String mode, RemoteActivityData chat) → void
sendEvent(RTCEvents event) → void
sendMainChatControllerEvent(RTCEvents event) → void
sendMessageToUI(String? message) → void
sendPrivateAction(ActionModel action, String? identity) Future<void>
sendPrivateChatEvent(RTCEvents event) → void
sendPrivateChatHistory(String? identity) → void
sendPrivateMessage(String? identity, String? name, String userMessage) Future<void>
sendPublicChatEvent(RTCEvents event) → void
sendPublicChatHistory(String? identity) → void
sendPublicMessage(String userMessage) Future<void>
sendUploadAttachmentEvent(RTCEvents event) → void
setAnnotationActive(bool active, {String? sharerIdentity}) → void
setAnnotationColor(String color) → void
setAnnotationTool(String tool) → void
setAnnotationWidth(double width) → void
setAudioInterrupted(bool value) → void
setCoHost(bool isCoHost) → void
setHandRaised(RemoteActivityData remoteData) → void
setHandRaisedForLocal(ActionModel action) → void
setMyHandRaised(bool isHandRaised) → void
setPrivateChatIdentity(String identity) → void
setPrivateChatUserName(String name) → void
setRecording(bool isRecording) → void
setTranscriptionLanguage(LanguageModel selectedLanguage, Function transcriptionEnabled) → void
shouldUpdateReaction(List<Reaction> reactions, String identity, String newEmoji) bool
startLobbyCheck() → void
startReactionCheck() → void
startRecording({bool isNeedToShowError = true}) → void
startRecordingConsent() → void
startRecordingConsentFlow() → void
startTranscription() → void
startTranscriptionAgent(LanguageModel selectedLanguage) → void
stopHandRaisedForAll() → void
stopLobbyCheck() → void
stopRecording({bool isNeedToShowError = true}) → void
stopTranscription() → void
storeMeetingDetails() → void
syncRaiseHand(List<RaisedHand>? serverList) → void
toString() String
A string representation of this object.
inherited
translateText(TranscriptionModel transcriptionData, {Function? callBack}) → void
undoLastAnnotationStroke(String sharerIdentity, String localIdentity) AnnotationStroke?
Removes and returns the last stroke drawn by localIdentity for undo.
unregisterCaption() → void
updateAdminList(RemoteParticipant participant) → void
updateAnnotationConsent(bool value) → void
updateAnnotationPermissionForParticipant(String participantIdentity, bool value) → void
updateAudioPermission(bool value) → void
updateAudioPermissionForParticipant(String participantIdentity, bool value) → void
updateChatAttachmentConsent(bool value) → void
updateIdentityToNameMap() → void
updateParticipantDrawerConsent(bool isHidden) → void
updateParticipantLanguage(LanguageModel transcriptionLanguage) → void
updateParticipantName({String? participant, required String newName}) → void
updateRecordingConsentStatus(bool status, {bool needToUpdateLocally = false}) → void
updateScreenShareConsent(bool value) → void
updateVideoPermission(bool value) → void
updateVideoPermissionForParticipant(String participantIdentity, bool value) → void
uploadAttachment(File file, Function? onUploadSuccess) → void
uploadPrivateAttachment(String identity, String name, File file, Function? onUploadSuccess) → void
verifyRecordingConsent(RemoteActivityData remoteData) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited